# Superstore

Categorical data generator

[![Build Status](https://github.com/timkpaine/superstore/workflows/Build%20Status/badge.svg?branch=main)](https://github.com/timkpaine/superstore/actions?query=workflow%3A%22Build+Status%22)
[![Coverage](https://codecov.io/gh/timkpaine/superstore/branch/main/graph/badge.svg)](https://codecov.io/gh/timkpaine/superstore)
[![License](https://img.shields.io/github/license/timkpaine/superstore.svg)](https://github.com/timkpaine/superstore)
[![PyPI](https://img.shields.io/pypi/v/superstore.svg)](https://pypi.python.org/pypi/superstore/)

## Install

Install from pip

`pip install superstore`

or from source

`python setup.py install`

## License

This software is licensed under the Apache 2.0 license. See the
[LICENSE](LICENSE) and [AUTHORS](AUTHORS) files for details.
